@@ -16,15 +16,6 @@ class Site extends \Blue2\Common\Site
         $this->setupControllers();
     }
 
-    public function no_redirect_on_404($redirect_url)
-    {
-        if(is_404())
-        {
-            return false;
-        }
-        return $redirect_url;
-    }
-
     public function overwriteCPTRequest($query) {
         // If query doesn't contain locations, just return the query
         if (strpos($query->request, 'locations') === false) {
@@ -41,12 +32,7 @@ class Site extends \Blue2\Common\Site
                 'name' => $pageName
             ));
 
-            $experienceResult = get_posts(array(
-                'post_type' => 'experience',
-                'name' => $pageName
-            ));
-
-            if (count($experienceResult) < 1 && count($plotResult) < 1 ) {
+            if (count($plotResult) < 1 ) {
                 //never matched any of our requests
                 return $query;
             } 
@@ -61,7 +47,40 @@ class Site extends \Blue2\Common\Site
 
                 $query->query_vars = $new_query;
                 return $query;
-            } elseif($experienceResult) {
+            } else {
+                return $query;
+            }
+    
+        } else {
+            return $query;
+        }
+    }
+
+    public function customExperienceRequest($query) {
+        // If query doesn't contain locations, just return the query
+        if (strpos($query->request, 'experiences') === false) {
+            return $query;
+        }
+        
+        if ( count($query->query_vars) > 0 && ! empty($query->query_vars['post_type'])) {
+            // The request contains the string that was requested.
+            $pageName = basename($query->request);
+    
+            // Check if post with the requested slug exists in your custom post type
+            $experienceResult = get_posts(array(
+                'post_type' => 'experience',
+                'name' => $pageName
+            ));
+
+            $pageResult= get_page_by_title( ucfirst($pageName) );
+
+            if (count($experienceResult) < 1 && count($pageResult) < 1 ) {
+                //never matched any of our requests
+                return $query;
+            }
+
+            if($experienceResult) {
+                //load experience by default
                 $new_query = array(
                     'page' => '',
                     'experience' => $pageName,
@@ -71,34 +90,10 @@ class Site extends \Blue2\Common\Site
 
                 $query->query_vars = $new_query;
                 return $query;
-            }
-            else {
-                return $query;
-            }
-    
-        } else {
-            return $query;
-        }
-    }
+            } else if($pageResult) {
+                // if no post then check for page
+                $pageResult= get_page_by_title( ucfirst($pageName) );
 
-    public function overwriteExperiencePage($query) {
-        if (strpos($query->request, 'locations') === false) {
-            return $query;
-        } 
-
-        if ( count($query->query_vars) > 0 && empty($query->query_vars['post_type'])) {
-            // The request contains the string that was requested.
-            $pageName = basename($query->request);
-    
-            // Check if post with the requested slug exists in your custom post type
-            $result= get_page_by_title( ucfirst($pageName) );
-
-            if (count($result) < 1) {
-                //never matched any of our requests
-                return $query;
-            } 
-            
-            if($result) {
                 $new_query = array(
                     'post_type'  => 'page', 
                     'name' => ucfirst($pageName) 
@@ -106,13 +101,10 @@ class Site extends \Blue2\Common\Site
 
                 $query->query_vars = $new_query;
                 return $query;
-            }
-            else {
+            } else {
+                //no page or post found
                 return $query;
             }
-    
-        } else {
-            return $query;
         }
     }
 
@@ -123,7 +115,8 @@ class Site extends \Blue2\Common\Site
             'footer_menu' => 'Footer Menu',
             'quick_links' => 'Quick Links',
             'help_links' => 'Help Links',
-            'legal_links' => 'Footer Legal Links'
+            'legal_links' => 'Footer Legal Links',
+            '404_links' => '404 Not Found Links'
         ]);
     }
 
@@ -137,9 +130,7 @@ class Site extends \Blue2\Common\Site
         // Empty
     }
 
-    private function registerFilters(){
-        add_filter('redirect_canonical', [$this,'no_redirect_on_404']);
-
+    private function registerFilters() {
         add_filter( 'ninja_forms_render_options', [$this, 'render_park_locations'] ,10,2);
 
         add_filter( 'post_type_link', [$this,'change_plot_link'], 1, 3 );
@@ -164,7 +155,7 @@ class Site extends \Blue2\Common\Site
 
         add_action('parse_request', [$this, 'overwriteCPTRequest'], 10, 1);
 
-        add_action('parse_request', [$this, 'overwriteExperiencePage'], 10, 1);
+        add_action('parse_request', [$this, 'customExperienceRequest'], 10, 1);
 
         if (isset($_GET['lodge_search']) && $_GET['lodge_search'] == 1){
             add_filter('pre_get_posts',[$this,'lodge_Search_filter']);
@@ -188,6 +179,7 @@ class Site extends \Blue2\Common\Site
 
     public function registerCustomTaxonomy() 
     {
+        //locations
         $labels = array(
             'name' => _x( 'Locations', 'taxonomy general name' ),
             'singular_name' => __( 'Locations', 'taxonomy singular name' ),
@@ -215,6 +207,35 @@ class Site extends \Blue2\Common\Site
             'update_count_callback' => '_update_post_term_count',
             'query_var' => true,
             'rewrite' => array( 'slug' => 'locations' ),
+        ));
+
+        $labels = array(
+            'name' => _x( 'Experience Type', 'taxonomy general name' ),
+            'singular_name' => __( 'Type', 'taxonomy singular name' ),
+            'search_items' =>  __( 'Search Types' ),
+            'popular_items' => __( 'Popular Types' ),
+            'all_items' => __( 'All Types' ),
+            'parent_item' => null,
+            'parent_item_colon' => null,
+            'edit_item' => __( 'Edit Type' ), 
+            'update_item' => __( 'Update Type' ),
+            'add_new_item' => __( 'Add New Type' ),
+            'new_item_name' => __( 'New Type Name' ),
+            'separate_items_with_commas' => __( 'Separate types with commas' ),
+            'add_or_remove_items' => __( 'Add or remove types' ),
+            'choose_from_most_used' => __( 'Choose from the most used types' ),
+            'menu_name' => __( 'Experience type' ),
+        );
+        
+        register_taxonomy('types','experience', array(
+            'hierarchical' => true,
+            'labels' => $labels,
+            'show_ui' => true,
+            'show_in_rest' => true,
+            'show_admin_column' => true,
+            'update_count_callback' => '_update_post_term_count',
+            'query_var' => true,
+            'rewrite' => array( 'slug' => 'locations/ruthven-falls/experiences/' ),
           ));
     }
 
@@ -229,7 +250,7 @@ class Site extends \Blue2\Common\Site
 
     public function change_plot_link( $post_link, $id = 0 ) {
         $post = get_post( $id );
-        if( $post->post_type == 'plot' || $post->post_type == 'experience' ) 
+        if( $post->post_type == 'plot') 
         {
            if ( is_object( $post ) ) {
               $terms = wp_get_object_terms( $post->ID, array('locations') );
@@ -247,10 +268,6 @@ class Site extends \Blue2\Common\Site
             $args['rewrite']['slug'] = 'locations/%cat%';
         }
 
-        if ( $post_type == 'experience') {
-            $args['rewrite']['slug'] = 'locations/%cat%/experiences';
-        }
-
         return $args;
     }
 
@@ -316,7 +333,9 @@ class Site extends \Blue2\Common\Site
                 
                 The site plan is the image used for the image map on the locations page.
                 
-                The 3d walkthrough is the matterport link provided, and the location is a Google Embed code you can get from the share section of Google Maps.',
+                The 3d walkthrough is the matterport link provided, and the location is a Google Embed code you can get from the share section of Google Maps.
+                
+                To show different experiences on the locations experiences page, you can set experiences in the experience grid.',
                             'new_lines' => 'wpautop',
                             'esc_html' => 0,
                         ),
